# Masonite Logging Package

This package is currently under a redesign. More docs to follow soon. Any documentation here seen is subject to change

Still Need to:

- [ ] Write Tests
- [ ] Add Docstrings
- [ ] Design in a way where it can be used outside of Masonite
- [ ] Add ability to create a custom channel and custom driver
- [ ] Add ability to add channels and drivers to the manager
- [ ] Write documentation
